summaryrefslogtreecommitdiffstats
path: root/lib/Fetcher/IFeedFetcher.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Fetcher/IFeedFetcher.php')
-rw-r--r--lib/Fetcher/IFeedFetcher.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/lib/Fetcher/IFeedFetcher.php b/lib/Fetcher/IFeedFetcher.php
index aaba9de67..bfa737805 100644
--- a/lib/Fetcher/IFeedFetcher.php
+++ b/lib/Fetcher/IFeedFetcher.php
@@ -14,6 +14,8 @@
namespace OCA\News\Fetcher;
use FeedIo\Reader\ReadErrorException;
+use OCA\News\Db\Feed;
+use OCA\News\Db\Item;
interface IFeedFetcher
{
@@ -29,7 +31,7 @@ interface IFeedFetcher
* @param string|null $user if given, basic auth is set for this feed
* @param string|null $password if given, basic auth is set for this feed. Ignored if user is empty
*
* @return array an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items
*
* @throws ReadErrorException if the Feed-IO fetcher encounters a problem
@@ -29,7 +31,7 @@ interface IFeedFetcher
* @param string|null $password if given, basic auth is set for this feed. Ignored if user is empty
*
- * @return array an array containing the new feed and its items, first
+ * @return <Feed, Item[]> an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items
*